//function [h,ax,BigAx,patches,pax] = plotmatrix(x,y,param1,param2)
function [h]=nan_plotmatrix(x,y,param1,param2)
// Scatter plot matrix.
// Calling Sequence
// nan_plotmatrix(Y) 
// nan_plotmatrix(X,Y)
// nan_plotmatrix(...,LineSpec)
// nan_plotmatrix(AX,...)
// [H] = nan_plotmatrix(...)
// Parameters
// LineSpec: line specification, '.' is the default (see help plot)
// AX: uses AX as the BigAx instead of gca()
// H: list of handles  to the objects 
// Description
//   plotmatrix(X,Y) scatter plots the columns of X against the columns
//   of Y.  If X is P-by-M and Y is P-by-N, PLOTMATRIX will produce a
//   N-by-M matrix of axes. plotmatrix(Y) is the same as plotmatrix(Y,Y)
//   except that the diagonal will be replaced by hist(Y(:,i)).
//   
//   Examples
//       x = rand(50,3,'normal'); y = x*[-1 2 1;2 0 1;1 -2 3;]';
//       nan_plotmatrix(y,'r*')
//   Authors
//   H. Nahrstaedt


[nargout,nargin]=argn(0);
if nargin<1
    error('Requires one Parameter');
elseif nargin <3 then
     param1=[];
     param2=[];
elseif nargin < 4 then
     param2=[];
end
// Accept an axes as the first arg, and plot into it.
if nargin>0 & sum(length(x))==1 & typeof(x)=="handle"
    // Get the axes, and shift the remaining args down by one.
    cax = x;
    x = y;
    if nargin > 2
        y = param1;
        if nargin > 3
            param1 = param2;
            param2=[];
        end;
    end
    nin = nargin - 1;
else
    cax = gca();
    nin = nargin;
end


sym = '.'; // Default scatter plot symbol.
dohist = 0;

if type(param1)==10,
    sym = param1;
//     [l,c,m,msg] = colstyle(sym);
//     if ~isempty(msg), error(msg); end
    nin = nin - 1;
end

if type(y)==10,
    sym = y;
//     [l,c,m,msg] = colstyle(sym);
//     if ~isempty(msg), error(msg); end
    nin = nin - 1;
end

if nin==1, // plotmatrix(y)
    rows = size(x,2); cols = rows;
    x = x; y = x;
    dohist = 1;
elseif nin==2, // plotmatrix(x,y)
    rows = size(y,2); cols = size(x,2);
    x = x; y = y;
else
    error('Invalid marker specification. Type ''help plot''.');
end

// Don't plot anything if either x or y is empty
if isempty(rows) | isempty(cols),
    if nargout>0, h = []; ax = []; BigAx = []; end
    return
end

if length(size(x))>2 | length(size(y))>2,
    error('X and Y must be 2-D.')
end
if size(x,1)~=size(y,1) | size(x,2)~=size(y,2),
    error('X and Y must have the same number of rows and pages.');
end

// Create/find BigAx and make it invisible
// BigAx = newplot(cax);
BigAx=cax;
BigAxParent = get(BigAx,'Parent');


if ~isempty(strindex(sym,'.')),
       pos = get(BigAxParent,'axes_size');
       markersize = max(0,min(15,round(1*min(pos)/max(1,size(x,1))/max(rows,cols))));
else
    markersize = 3;//get(0,'DefaultLineMarkerSize');
end
offset=50;
// Create and plot into axes
ax=list();
hh = list();
 pos = [get(BigAx.parent,'figure_position'),get(BigAx.parent,'figure_size')];
width = (pos(3)-offset)/cols;
height = (pos(4)-offset)/rows;
 space = .02; // 2 percent space between axes
 pos(1:2) = pos(1:2) + space*[width height];
// m = size(y,1);
// k = size(y,3);
 xlim = zeros(rows, cols, 2);
 ylim = zeros(rows, cols, 2);

for i=rows:-1:1,
   for j=cols:-1:1,
        axPos = [(j-1)*width+offset (i-1)*height   width*(1-space) height*(1-space)];
        ax(rows*(i-1)+j) = newaxes();//axes('Position',axPos, 'visible', 'on', 'Box','on');
        ax(rows*(i-1)+j).axes_bounds=axPos./[pos(3),pos(4),pos(3),pos(4)];
        //hh(rows*(i-1)+j) = gca();

       if i==j & dohist
         [nn,xx] = nan_hist(y(:,i));
         bar(xx,nn);
         ax(rows*(i-1)+j).auto_ticks(1)='on';
       else
        plot(x(:,j),y(:,i),sym);
        ax(rows*(i-1)+j).children.children.mark_size=markersize;
       end;
       ax(rows*(i-1)+j).tight_limits="on";
         xlim(i,j,:) = ax(rows*(i-1)+j).data_bounds(:,1);
         ylim(i,j,:) = ax(rows*(i-1)+j).data_bounds(:,2);

    end
end
// 
 xlimmin = mtlb_min(xlim(:,:,1),[],1); xlimmax = mtlb_max(xlim(:,:,2),[],1);
 ylimmin = mtlb_min(ylim(:,:,1),[],2); ylimmax = mtlb_max(ylim(:,:,2),[],2);
// 
// // Try to be smart about axes limits and labels.  Set all the limits of a
// // row or column to be the same and inset the tick marks by 10 percent.
 inset = .15;
 for i=1:rows,
  for j=1:cols
     //set(ax(i,1),'ylim',[ylimmin(i,1) ylimmax(i,1)])
    
      ax(rows*(i-1)+j).data_bounds(:,1)=[xlimmin(1,j) xlimmax(1,j)]';
      dx = diff(ax(rows*(i-1)+j).data_bounds(:,1))*inset;
//     set(ax(:,j),'xlim',[xlimmin(1,j)-dx(j) xlimmax(1,j)+dx(j)])
     ax(rows*(i-1)+j).data_bounds(:,1)=[xlimmin(1,j)-dx xlimmax(1,j)+dx]';

     if (i==j & dohist)
       ax(rows*(i-1)+j).data_bounds(:,2)=[0 ylimmax(i,1)]';
       dy = diff(ax(rows*(i-1)+j).data_bounds(:,2))*inset;
       ax(rows*(i-1)+j).data_bounds(:,2)=[0 ylimmax(i,1)+dy]';
     else
        ax(rows*(i-1)+j).data_bounds(:,2)=[ylimmin(i,1) ylimmax(i,1)]';
        dy = diff(ax(rows*(i-1)+j).data_bounds(:,2))*inset;
        //set(ax(i,:),'ylim',[ylimmin(i,1)-dy ylimmax(i,1)+dy])
        ax(rows*(i-1)+j).data_bounds(:,2)=[ylimmin(i,1)-dy ylimmax(i,1)+dy]';
     end;
  end;
 end

 for i=1:rows-1,
  for j=2:cols
  ax(rows*(i-1)+j).x_ticks.labels=[''];
  ax(rows*(i-1)+j).y_ticks.labels=[''];
   ax(rows*(i-1)+j).margins=[0.01 0.01 0.01 0.01];
end
  
end
for j=2:cols
 ax(rows*(rows-1)+j).y_ticks.labels=[''];
 ax(rows*(rows-1)+j).margins=[0.01 0.01 0.01 0.01];
end;
 for i=1:rows-1,
 ax(rows*(i-1)+1).x_ticks.labels=[''];
ax(rows*(i-1)+1).margins=[0.01 0.01 0.01 0.01];
end;
ax(rows*(rows-1)+1).margins=[0.01 0.01 0.01 0.01];


if nargout~=0,
    h = ax;
end
endfunction
